@@ -1,10 +1,11 @@
 #include "help.h"
 
-void Help::showHelp(std::string_view option) {
+
+void Help::showHelp(const std::string& option) {
     if (option == "-v" || option == "--help") {
         std::cout << "libAIConnect\n\n"
                      "A library for utilizing the API of OpenAI, Claude AI, Google Gemini or Mistral AI.\n\n";
-        std::cout << "Version 1.0.3\n\n";
+        std::cout << "Version 1.0.4\n\n";
         std::cout << "The library is released under GNU Lesser General Public License version 3.0,\n"
                      "while the executable program is released under Apache License version 2.0.\n\n";
         std::cout << "The program dynamically uses the library libcurl.\n"
