@@ -166,7 +166,7 @@ std::string Options::receiveMultiLines() {
     return inputtedText;
 }
 
-std::array<std::string, 6> Options::getOptions(int argc, char** argv) {
+std::array<std::string, 6> Options::getOptions(int argc, const std::vector<std::string>& argVector) {
     // All available options.
     std::vector<std::string> options = {
         "--add-key",  // Add or update an API key.
@@ -197,7 +197,7 @@ std::array<std::string, 6> Options::getOptions(int argc, char** argv) {
      * As argv[0] is the program's name, i begins at 1.
      */
     for (int i = 1; i < argc; ++i) {
-        inputtedArguments.emplace_back(argv[i]);
+        inputtedArguments.emplace_back(argVector[i]);
     }
 
     // Recognize options.
