@@ -2,14 +2,14 @@
 #define LIBAICONNECT_OPTIONS_H
 
 #include <iostream>
-#include <expected>
+#include <vector>
 #include <unordered_map>
 
 class Options {
 
 public:
 
-    static std::array<std::string, 6> getOptions(int argc, char** argv);
+    static std::array<std::string, 6> getOptions(int argc, const std::vector<std::string>& argVector);
 
 private:
 
